django-admirarchy documentation
===============================
https://github.com/idlesign/django-admirarchy



Description
-----------

*Django Admin addon to navigate through hierarchies.*


Have you ever wanted Django Admin to be able to navigate through hierarchies?

Without existing models modifications? Yeah!

Admirarchy does it in an old-school way, just like Norton Commander and Co - one level at a time.

Hierarchies described as adjacency lists and nested sets are supported.


Requirements
------------

.. image:: https://idlesign.github.io/lbc/py2-lbc.svg
   :target: https://idlesign.github.io/lbc/
   :alt: LBC Python 2

----

1. Python 2.7+, 3.5+
2. Django 1.8+
3. Django Admin contrib



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    advanced
